@@ -1,12 +1,12 @@
 package Lingua::Word::Parser;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Parse a word into known and unknown parts
+# ABSTRACT: Parse a word into scored known and unknown parts
 
 use strict;
 use warnings;
 
-our $VERSION = '0.0802';
+our $VERSION = '0.0803';
 
 use Bit::Vector;
 use DBI;
@@ -18,6 +18,7 @@ memoize('_does_not_overlap');
 memoize('power');
 memoize('_reconstruct');
 memoize('_grouping');
+memoize('score');
 memoize('score_parts');
 memoize('_rle');
 memoize('_or_together');
@@ -206,13 +207,13 @@ sub score {
     my $parts = $self->score_parts( $open_separator, $close_separator );
 
     for my $mask ( keys %$parts ) {
+        my $familiarity = sprintf "%.2f chunks / %.2f chars", @{ $self->_familiarity($mask) };
+
         for my $element ( @{ $parts->{$mask} } ) {
             my $score = sprintf "%d:%d chunks / %d:%d chars",
                 $element->{score}{knowns}, $element->{score}{unknowns},
                 $element->{score}{knownc}, $element->{score}{unknownc};
 
-            my $familiarity = sprintf "%.2f chunks / %.2f chars", @{ $self->_familiarity($mask) };
-
             my $part = join ', ', @{ $element->{partition} };
 
             my $defn = join ', ', @{ $element->{definition} };
@@ -412,11 +413,11 @@ __END__
 
 =head1 NAME
 
-Lingua::Word::Parser - Parse a word into known and unknown parts
+Lingua::Word::Parser - Parse a word into scored known and unknown parts
 
 =head1 VERSION
 
-version 0.0802
+version 0.0803
 
 =head1 SYNOPSIS
 
